Function wasmtime_runtime::mpk::allow
source · pub fn allow(mask: ProtectionMask)Expand description
Only allow access to pages marked by the keys set in mask.
Any accesses to pages marked by another key will result in a SIGSEGV
fault.